@@ -9,7 +9,7 @@ from codeguru_profiler_agent.agent_metadata.fleet_info import DefaultFleetInfo
 # NOTE: Please do not alter the value for the following constants without the full knowledge of the use of them.
 # These constants are used in several scripts, including setup.py.
 __agent_name__ = "CodeGuruProfiler-python"
-__agent_version__ = "1.0.6"
+__agent_version__ = "1.2.1"
 
 
 def look_up_fleet_info(
@@ -67,7 +67,7 @@ class AgentMetadata:
         return self._fleet_info
 
     def serialize_to_json(self, sample_weight, duration_ms, cpu_time_seconds,
-                          average_num_threads, overhead_ms, memory_usage_mb):
+                          average_num_threads, overhead_ms, memory_usage_mb, total_sample_count):
         """
         This needs to be compliant with agent profile schema.
         """
@@ -89,7 +89,8 @@ class AgentMetadata:
                 "cpuTimeInSeconds": cpu_time_seconds,
                 "metrics": {
                     "numThreads": average_num_threads
-                }
+                },
+                "numTimesSampled": total_sample_count
             }
             if overhead_ms != 0:
                 self.json_rep["agentOverhead"]["timeInMs"] = overhead_ms
