@@ -10,27 +10,37 @@ from pathlib import Path
 GZIP_BALANCED_COMPRESSION_LEVEL = 6
 DEFAULT_FRAME_COMPONENT_DELIMITER = ":"
 
-
 def _get_module_path(file_path, sys_paths):
     """
     We tried to remove the python library root path in order to give a reasonable expression of the module path.
     For example, /tmp/bin/python/site-packages/great_app/simple_expansions/simple_interface.py
     will get turned into great_app.simple_expansions.simple_interface given that the syspath contains
     /tmp/bin/python/site-packages
+
+    We are making sure we're removing the current path for this special usecase, by checking if it contains "/./".
+    For example, '/Users/mirelap/Documents/workspace/JSON/aws-codeguru-profiler-python-demo-application/sample-demo-django-app/./polls/views.py'
+    will get turned into `polls.views' given that the file path contains the current path.
+    This should not happen usually, but we've found a case where the "/." is added when calling traceback.walk_stack(..)
+    in a uwsgi application. Check sampling_utils.py file for details.
+
+    sampling_utils.py returns different values when calling traceback.walk_stack(..) for uwsgi vs non-uwsgi
+    for Python 3.8.10-Python 3.9.2.
+    Examples of results:
+    - file '/Users/mirelap/Documents/workspace/JSON/aws-codeguru-profiler-python-demo-application/sample-demo-django-app/./polls/views.py', line 104, code get_queryset>, 104
+    - file '/Users/mirelap/Documents/workspace/JSON/aws-codeguru-profiler-python-demo-application/sample-demo-django-app/polls/views.py', line 104, code get_queryset>, 104
     """
     module_path = file_path
 
     if platform.system() == "Windows":
         # In Windows, separator can either be / or \ from experimental result
-        file_path = file_path.replace("/", os.sep)
+        module_path = module_path.replace("/", os.sep)
 
-    for root in sys_paths:
-        if root in file_path:
-            module_path = file_path.replace(root, "")
-            break
+    # remove prefix path
+    module_path = _remove_prefix_path(module_path, sys_paths)
 
     # remove suffix
     module_path = str(Path(module_path).with_suffix(""))
+
     # remove drive (applicable for WINDOWS customers)
     module_path = os.path.splitdrive(module_path)[1]
 
@@ -42,6 +52,20 @@ def _get_module_path(file_path, sys_paths):
     return module_path
 
 
+def _remove_prefix_path(module_path, sys_paths):
+    if "/./" in module_path and platform.system() != "Windows":
+        module_path = module_path.replace("/./", "/")
+        current_path = str(Path().absolute())
+        if current_path != "/": # this may be Fargate
+            return module_path.replace(current_path, "")
+        return module_path
+
+    for root in sys_paths:
+        if root in module_path:
+            return module_path.replace(root, "")
+
+    return module_path
+
 class ProfileEncoder:
     """
     Encodes a given Profile into the JSON version of the ion-based profile format
@@ -99,11 +123,15 @@ class ProfileEncoder:
                 "start": int(self._profile.start),
                 "end": int(self._profile.end),
                 "agentMetadata": self._encode_agent_metadata(),
-                "callgraph": self._encode_call_graph(self._profile.callgraph)
+                "callgraph": self._encode_call_graph(self._profile.callgraph),
+                "debugInfo": self._encode_debug_info()
             }
 
             return json.dumps(profile_in_map)
 
+        def _encode_debug_info(self):
+            return self._profile.serialize_agent_debug_info_to_json()
+
         def _encode_agent_metadata(self):
             profile_duration_seconds = self._profile.get_active_millis_since_start() / 1000.0
             sample_weight = 1.0 if (profile_duration_seconds == 0) else self._profile.total_sample_count / profile_duration_seconds
@@ -115,7 +143,8 @@ class ProfileEncoder:
                         cpu_time_seconds=self._profile.cpu_time_seconds,
                         average_num_threads=average_num_threads,
                         memory_usage_mb=self._convert_to_mb(self._profile.get_memory_usage_bytes()),
-                        overhead_ms=self._profile.overhead_ms
+                        overhead_ms=self._profile.overhead_ms,
+                        total_sample_count = self._profile.total_sample_count
             )
 
         def _convert_to_mb(self, bytes_to_convert):
